mod config;

use crate::config::Config;
use rand::seq::IteratorRandom;
use serde::{Deserialize, Serialize};

#[derive(Serialize, Deserialize)]
struct ApiResponse<T> {
    response: T,
}

#[derive(Serialize, Deserialize)]
struct SteamIdResponse {
    steamid: String,
    success: u8,
}

#[derive(Serialize, Deserialize, Clone)]
struct Game {
    appid: u32,
    name: Option<String>,
    playtime_2weeks: Option<u32>,
    playtime_forever: Option<u32>,
    img_icon_url: Option<String>,
    img_logo_url: Option<String>,
    has_community_visible_stats: Option<bool>,
}

#[derive(Serialize, Deserialize)]
struct GameList {
    game_count: i32,
    games: Vec<Game>,
}

impl GameList {
    fn new() -> GameList {
        GameList {
            game_count: 0,
            games: Vec::new(),
        }
    }

    fn update(&mut self) {
        let config = Config::new();
        match reqwest::blocking::get(format!("https://api.steampowered.com/IPlayerService/GetOwnedGames/v0001/?key={}&steamid={}&format=json&include_appinfo=true",
                                             config.steam_api_key,
                                             config.get_steam_id(Some(&config.user.username))
        )) {
            Ok(res) => {
                match res.text() {
                   Ok(text) => {
                       let api_response: ApiResponse<GameList>= serde_json::from_str(&text).unwrap();
                       self.games = api_response.response.games;
                   },
                    Err(_) => println!("Error getting list") ,
                }
            }
            Err(_) => println!("Error getting list") ,
        }
    }

    fn pick(&self) -> Option<Game> {
        self.games.iter().choose(&mut rand::rng()).cloned()
    }
}

fn main() {
    let mut game_list = GameList::new();
    game_list.update();

    println!("Time to play {}!", game_list.pick().unwrap().name.unwrap())
}
